package fortyonepost.com.psfaxn; // 41 Post - Created by DimasTheDriver on Sept/10/2012 . Part of the 'Android: get String resource at another XML namespace' post. Available at: http://www.41post.com/?p=4941.

import android.content.Context;
import android.content.res.Resources;
import android.preference.Preference;
import android.util.AttributeSet;
import android.view.View;
import android.widget.Button;

public class CustomPreference extends Preference
{
	//A string that holds the label that goes into the button
	private String buttonLabel = "";
	
	public CustomPreference(Context context, AttributeSet attrs) 
	{
		super(context, attrs);
		//Set the Preferences at the preferences screen from the 'custom_pref_layout.xml' file
		this.setLayoutResource(R.layout.custom_pref_layout);
		//Obtain the button label from the 'buttonLabel' attribute defined at the 'custom_namespace' XML namespace
		this.buttonLabel = GetAttributeStringValue(context, attrs, "http://your.pref.namespace.com", "buttonLabel", "Default Label");
	}

	@Override
	public void onBindView(View view)
	{
		super.onBindView(view);
		//Get a reference to the Button
		Button bt_prefButton = (Button)view.findViewById(R.id.bt_prefButton);
		//Set the label obtained from the GetAttributeStringValue() method
		bt_prefButton.setText(this.buttonLabel);
	}
	
	private String GetAttributeStringValue(Context context, AttributeSet attrs, String namespace, String name, String defaultValue) 
	{
		//Get a reference to the Resources
		Resources res = context.getResources();
		//Obtain a  String from the attribute
		String stringValue = attrs.getAttributeValue(namespace, name);
		//If the String is null 
		if(stringValue == null)
		{
			//set the return String to the default value, passed as a parameter
			stringValue = defaultValue;
		}
		//The String isn't null, so check if it starts with '@' and contains '@string/'
		else if( stringValue.length() > 1 && 
				 stringValue.charAt(0) == '@' && 
				 stringValue.contains("@string/") ) 
		{
			//Get the integer identifier to the String resource
			final int id = res.getIdentifier(context.getPackageName() + ":" + stringValue.substring(1), null, null);
			//Decode the string from the obtained resource ID
			stringValue = res.getString(id);
		} 
		//Return the string value
		return stringValue;
	}
}